@@ -63,6 +63,7 @@ describe 'tripleo::profile::base::cinder::volume' do
         end
       end
 
+
       context 'with only pure' do
         before :each do
           params.merge!({
@@ -91,6 +92,90 @@ describe 'tripleo::profile::base::cinder::volume' do
         end
       end
 
+      context 'with only xtremio' do
+        before :each do
+          params.merge!({
+            :cinder_enable_dellemc_xtremio_backend  => true,
+            :cinder_enable_iscsi_backend            => false,
+          })
+        end
+        it 'should configure only xtremio' do
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_xtremio')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
+          is_expected.to contain_class('tripleo::profile::base::cinder')
+          is_expected.to contain_class('cinder::volume')
+          is_expected.to contain_class('cinder::backends').with(
+            :enabled_backends => ['tripleo_dellemc_xtremio']
+          )
+        end
+        context 'with multiple xtremio backends' do
+          # Step 5's hiera specifies two xtremio backend names
+          let(:params) { { :step => 5 } }
+          it 'should enable each backend' do
+            is_expected.to contain_class('cinder::backends').with(
+              :enabled_backends => ['tripleo_dellemc_xtremio_1', 'tripleo_dellemc_xtremio_2']
+            )
+          end
+        end
+      end
+
+      context 'with only powermax' do
+        before :each do
+          params.merge!({
+            :cinder_enable_dellemc_powermax_backend  => true,
+            :cinder_enable_iscsi_backend             => false,
+          })
+        end
+        it 'should configure only powermax' do
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_powermax')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
+          is_expected.to contain_class('tripleo::profile::base::cinder')
+          is_expected.to contain_class('cinder::volume')
+          is_expected.to contain_class('cinder::backends').with(
+            :enabled_backends => ['tripleo_dellemc_powermax']
+          )
+        end
+        context 'with multiple powermax backends' do
+          # Step 5's hiera specifies two powermax backend names
+          let(:params) { { :step => 5 } }
+          it 'should enable each backend' do
+            is_expected.to contain_class('cinder::backends').with(
+              :enabled_backends => ['tripleo_dellemc_powermax_1', 'tripleo_dellemc_powermax_2']
+            )
+          end
+        end
+      end
+
+      context 'with only sc' do
+        before :each do
+          params.merge!({
+            :cinder_enable_dellemc_sc_backend  => true,
+            :cinder_enable_iscsi_backend       => false,
+          })
+        end
+        it 'should configure only sc' do
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_sc')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
+          is_expected.to contain_class('tripleo::profile::base::cinder')
+          is_expected.to contain_class('cinder::volume')
+          is_expected.to contain_class('cinder::backends').with(
+            :enabled_backends => ['tripleo_dellemc_sc']
+          )
+        end
+        context 'with multiple sc backends' do
+          # Step 5's hiera specifies multiple sc backend names
+          let(:params) { { :step => 5 } }
+          it 'should enable each backend' do
+            is_expected.to contain_class('cinder::backends').with(
+              :enabled_backends => ['tripleo_dellemc_sc_1', 'tripleo_dellemc_sc_2']
+            )
+          end
+        end
+      end
+
       context 'with only dellsc' do
         before :each do
           params.merge!({
@@ -129,6 +214,25 @@ describe 'tripleo::profile::base::cinder::volume' do
         end
       end
 
+        context 'with only vxflexos' do
+        before :each do
+          params.merge!({
+            :cinder_enable_dellemc_vxflexos_backend => true,
+            :cinder_enable_iscsi_backend            => false,
+          })
+        end
+        it 'should configure only vxflexos' do
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::iscsi')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume')
+          is_expected.to contain_class('tripleo::profile::base::cinder')
+          is_expected.to contain_class('cinder::volume')
+          is_expected.to contain_class('cinder::backends').with(
+            :enabled_backends => ['tripleo_dellemc_vxflexos']
+          )
+        end
+      end
+
       context 'with only netapp' do
         before :each do
           params.merge!({
@@ -232,6 +336,10 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::pure')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellsc')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellps')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_sc')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_powermax')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
+          is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::dellemc_xtremio')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::netapp')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to_not contain_class('tripleo::profile::base::cinder::volume::nfs')
@@ -248,21 +356,29 @@ describe 'tripleo::profile::base::cinder::volume' do
       context 'with all tripleo backends' do
         before :each do
           params.merge!({
-            :cinder_enable_nfs_backend     => true,
-            :cinder_enable_rbd_backend     => true,
-            :cinder_enable_iscsi_backend   => true,
-            :cinder_enable_pure_backend    => true,
-            :cinder_enable_dellsc_backend  => true,
-            :cinder_enable_dellps_backend  => true,
-            :cinder_enable_netapp_backend  => true,
-            :cinder_enable_vrts_hs_backend => true,
+            :cinder_enable_nfs_backend              => true,
+            :cinder_enable_rbd_backend              => true,
+            :cinder_enable_iscsi_backend            => true,
+            :cinder_enable_pure_backend             => true,
+            :cinder_enable_dellps_backend           => true,
+            :cinder_enable_dellsc_backend           => true,
+            :cinder_enable_dellemc_sc_backend       => true,
+            :cinder_enable_dellemc_powermax_backend => true,
+            :cinder_enable_dellemc_vxflexos_backend => true,
+            :cinder_enable_dellemc_xtremio_backend  => true,
+            :cinder_enable_netapp_backend           => true,
+            :cinder_enable_vrts_hs_backend          => true,
           })
         end
         it 'should configure all backends' do
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::iscsi')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::pure')
-          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellsc')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellps')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellsc')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_sc')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_vxflexos')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_xtremio')
+          is_expected.to contain_class('tripleo::profile::base::cinder::volume::dellemc_powermax')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::netapp')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::veritas_hyperscale')
           is_expected.to contain_class('tripleo::profile::base::cinder::volume::nfs')
@@ -271,8 +387,9 @@ describe 'tripleo::profile::base::cinder::volume' do
           is_expected.to contain_class('tripleo::profile::base::cinder')
           is_expected.to contain_class('cinder::volume')
           is_expected.to contain_class('cinder::backends').with(
-            :enabled_backends => ['tripleo_iscsi', 'tripleo_ceph', 'tripleo_pure', 'tripleo_dellps',
-                                  'tripleo_dellsc', 'tripleo_netapp','tripleo_nfs','Veritas_HyperScale']
+            :enabled_backends => ['tripleo_iscsi', 'tripleo_ceph', 'tripleo_pure', 'tripleo_dellps', 'tripleo_dellsc',
+                                  'tripleo_dellemc_sc', 'tripleo_dellemc_powermax', 'tripleo_dellemc_vxflexos', 'tripleo_dellemc_xtremio', 'tripleo_netapp',
+                                  'tripleo_nfs', 'Veritas_HyperScale']
           )
         end
       end
@@ -297,12 +414,42 @@ describe 'tripleo::profile::base::cinder::volume' do
         context 'with internal tls enabled' do
           before :each do
             params.merge!({
-              :enable_internal_tls => true,
+              :enable_internal_tls    => true,
+              :etcd_certificate_specs => {
+                'service_certificate' => '/path/to/etcd.cert',
+                'service_key'         => '/path/to/etcd.key',
+              },
             })
           end
           it 'should configure coordination backend_url with https' do
             is_expected.to contain_class('cinder::coordination').with(
-              :backend_url => 'etcd3+https://127.0.0.1:2379',
+              :backend_url => 'etcd3+https://127.0.0.1:2379?cert_key=/path/to/etcd.key&cert_cert=/path/to/etcd.cert',
+            )
+          end
+        end
+
+        context 'with an ipv6 etcd_host' do
+          before :each do
+            params.merge!({
+              :etcd_host => 'fe80::1ff:fe23:4567:890a',
+            })
+          end
+          it 'should normalize it in the URI' do
+            is_expected.to contain_class('cinder::coordination').with(
+              :backend_url => 'etcd3+http://[fe80::1ff:fe23:4567:890a]:2379',
+            )
+          end
+        end
+
+        context 'with a named etcd_host' do
+          before :each do
+            params.merge!({
+              :etcd_host => 'etcdhost.localdomain',
+            })
+          end
+          it 'should craft a correct URI' do
+            is_expected.to contain_class('cinder::coordination').with(
+              :backend_url => 'etcd3+http://etcdhost.localdomain:2379',
             )
           end
         end
